﻿using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinSchedule;
using Infragistics.Win.UltraWinToolbars;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WGV_CustomContextMenu
{
    public partial class Form1 : Form
    {

        CellUIElement currentCell;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        { 
            setUpGanttTasks();
        }

        private void setUpGanttTasks()
        {
            Project quarterlyProject = this.ultraCalendarInfo1.Projects.Add("QuartlerlyProject", DateTime.Today);
            quarterlyProject.Key = "projkey1";

            Infragistics.Win.UltraWinSchedule.Task requirementsTask = this.ultraCalendarInfo1.Tasks.Add(DateTime.Today.AddDays(5), TimeSpan.FromDays(5), "Requirements");

            Infragistics.Win.UltraWinSchedule.Task budgetTask = ultraCalendarInfo1.Tasks.Add(DateTime.Today, TimeSpan.FromDays(2), "Budget Analysis");
            budgetTask.Deadline = DateTime.Today.AddDays(2);
            Owner budgetOwner = this.ultraCalendarInfo1.Owners.Add("BudgetOwner", "Bill Isacky");
            budgetTask.Resources.Add(budgetOwner);
            budgetTask.SetDuration(budgetTask.Duration, Infragistics.Win.TimeSpanFormat.Hours);

            Infragistics.Win.UltraWinSchedule.Task teamTask = ultraCalendarInfo1.Tasks.Add(DateTime.Today.AddDays(3), TimeSpan.FromDays(4), "Team Allocation");
            teamTask.ConstraintDateTime = DateTime.Today.AddDays(4);
            teamTask.Constraint = TaskConstraint.FinishNoLaterThan;
            teamTask.SetDuration(teamTask.Duration, Infragistics.Win.TimeSpanFormat.Hours);


            Infragistics.Win.UltraWinSchedule.Task implemetationTask = this.ultraCalendarInfo1.Tasks.Add(DateTime.Now.AddDays(1), TimeSpan.FromDays(4), "Implementation");
            implemetationTask.SetDuration(TimeSpan.FromDays(3), Infragistics.Win.TimeSpanFormat.Hours);

            Infragistics.Win.UltraWinSchedule.Task frontendTask = ultraCalendarInfo1.Tasks.Add(DateTime.Now.AddDays(7), TimeSpan.FromDays(3), "GUI Design");
            frontendTask.Milestone = true;
            frontendTask.PercentComplete = 40;
            frontendTask.Dependencies.Add(budgetTask, TaskDependencyType.StartToStart);
            frontendTask.Dependencies.Add(teamTask, TaskDependencyType.FinishToStart);
            frontendTask.SetDuration(frontendTask.Duration, Infragistics.Win.TimeSpanFormat.Hours);

            teamTask.Project = quarterlyProject;
            budgetTask.Project = quarterlyProject;
            frontendTask.Project = quarterlyProject;
            implemetationTask.Project = quarterlyProject;
            requirementsTask.Project = quarterlyProject;

            this.ultraGanttView1.CalendarInfo = this.ultraCalendarInfo1;
            this.ultraGanttView1.Project = this.ultraGanttView1.CalendarInfo.Projects[1];
        }

        private void ultraGanttView1_MouseDown(object sender, MouseEventArgs e)
        {
           
            if (e.Button == System.Windows.Forms.MouseButtons.Right &&
                ultraGanttView1.UIElement.ElementFromPoint(e.Location).
                GetAncestor(typeof(RowUIElement)) != null)
            {
                var popupMenu = ultraToolbarsManager1.Tools[0] as PopupMenuTool;
                popupMenu.ShowPopup(Control.MousePosition);
                currentCell = ultraGanttView1.UIElement.ElementFromPoint(e.Location).
                    GetAncestor(typeof(CellUIElement)) as CellUIElement;
                
            }
        }

        private void ultraToolbarsManager1_ToolClick(object sender, Infragistics.Win.UltraWinToolbars.ToolClickEventArgs e)
        {
            switch (e.Tool.Key)
            {
                case "ShowRow":
                    showCurrentRow((RowUIElement)e.Tool.Tag);
                    break;
                case "ShowColumn":
                    showCurrentCol((CellUIElement)e.Tool.Tag);
                    break;
                default:
                    break;
            }
        }

        private void showCurrentCol(CellUIElement cell)
        {
            MessageBox.Show(currentCell.Cell.Column.Key);
        }

        private void showCurrentRow(RowUIElement row)
        {
            MessageBox.Show(currentCell.Cell.Row.Index.ToString());
        }

        private void ultraGanttView1_ContextMenuInitializing(object sender, Infragistics.Win.UltraWinGanttView.ContextMenuInitializingEventArgs e)
        {
            e.Cancel = true;
        }
    }
}
